@@ -1,4 +1,4 @@
 from .sharpify import View;
 from .sharpify import httpGet, httpPost;
-from .sharpify import use_mvc;
+from .sharpify import use_mvc, use_htmlAttributes;
 
